@@ -273,15 +273,18 @@ class DbusMemberAbstract:
         self.python_name = camel_case_to_snake_case(self.method_name)
 
         self.is_deprecated = False
-        self.is_unpriveledged = False
+        self.is_priveledged = False
 
         self.iter_sub_elements(element)
 
+    def _can_use_unpivileged(self) -> bool:
+        return True
+
     def _flags_iter(self) -> Iterator[str]:
         if self.is_deprecated:
             yield 'DbusDeprecatedFlag'
 
-        if self.is_unpriveledged:
+        if not self.is_priveledged and self._can_use_unpivileged():
             yield 'DbusUnprivilegedFlag'
 
     @property
@@ -298,7 +301,7 @@ class DbusMemberAbstract:
         if annotation_name == 'org.freedesktop.DBus.Deprecated':
             self.is_deprecated = parse_str_bool(annotation_value)
         elif annotation_name == 'org.freedesktop.systemd1.Privileged':
-            self.is_unpriveledged = parse_str_bool(annotation_value)
+            self.is_priveledged = parse_str_bool(annotation_value)
         else:
             ...
 
@@ -414,6 +417,14 @@ class DbusMethodInrospection(DbusMemberAbstract):
         return DbusSigToTyping.result_typing(
             [x.dbus_type for x in self.result_args])
 
+    @property
+    def is_results_args_valid_names(self) -> bool:
+        return all((r.name is not None for r in self.result_args))
+
+    @property
+    def result_args_names_repr(self) -> str:
+        return repr(tuple(r.name for r in self.result_args))
+
     def __repr__(self) -> str:
         return (f"D-Bus Method: {self.method_name}, "
                 f"args: {self.args_names_and_typing}, "
@@ -421,12 +432,13 @@ class DbusMethodInrospection(DbusMemberAbstract):
 
 
 class DbusPropertyIntrospection(DbusMemberAbstract):
-    _EMITS_CHANGED_MAP: \
-        Dict[Union[bool, None, Literal['const', 'invalidates']], str] = {
-            True: 'DbusPropertyEmitsChangeFlag',
-            'invalidates': 'DbusPropertyEmitsInvalidationFlag',
-            'const': 'DbusPropertyConstFlag',
-        }
+    _EMITS_CHANGED_MAP: Dict[
+        Union[bool, Literal['const', 'invalidates']], str
+    ] = {
+        True: 'DbusPropertyEmitsChangeFlag',
+        'invalidates': 'DbusPropertyEmitsInvalidationFlag',
+        'const': 'DbusPropertyConstFlag',
+    }
 
     def __init__(self, element: Element):
         if element.tag != 'property':
@@ -434,8 +446,7 @@ class DbusPropertyIntrospection(DbusMemberAbstract):
 
         self.dbus_signature = element.attrib['type']
 
-        self.emits_changed: \
-            Union[bool, Literal['const', 'invalidates'], None] = None
+        self.emits_changed: Union[bool, Literal['const', 'invalidates']] = True
         self.is_explicit = False
 
         access_type = element.attrib['access']
@@ -448,6 +459,12 @@ class DbusPropertyIntrospection(DbusMemberAbstract):
 
         super().__init__(element)
 
+    def _can_use_unpivileged(self) -> bool:
+        # Only properties that have setters defined can use the
+        # unprivileged flags. The code generator does NOT generate
+        # setters.
+        return False
+
     def _flags_iter(self) -> Iterator[str]:
         emits_changed_str = self._EMITS_CHANGED_MAP.get(self.emits_changed)
         if emits_changed_str is not None:
@@ -490,6 +507,9 @@ class DbusSignalIntrospection(DbusMemberAbstract):
         self.args: List[DbusArgsIntrospection] = []
         super().__init__(element)
 
+    def _can_use_unpivileged(self) -> bool:
+        return False
+
     def _parse_arg(self, arg: Element) -> None:
         new_arg = DbusArgsIntrospection(arg)
 
@@ -507,6 +527,14 @@ class DbusSignalIntrospection(DbusMemberAbstract):
         return DbusSigToTyping.result_typing(
             [x.dbus_type for x in self.args])
 
+    @property
+    def is_args_valid_names(self) -> bool:
+        return all((a.name is not None for a in self.args))
+
+    @property
+    def args_names_repr(self) -> str:
+        return repr(tuple(a.name for a in self.args))
+
 
 class DbusInterfaceIntrospection:
     def __init__(self, element: Element):
@@ -555,38 +583,44 @@ SKIP_INTERFACES = {
     'org.freedesktop.DBus.ObjectManager',
 }
 
+
 INTERFACE_TEMPLATES: Dict[str, str] = {
-    "generic_no_members": r"...  # Interface has no members",
+    "generic_no_members": """\
+...  # Interface has no members
+""",
     "generic_method_flags": (
-        r"""
-{%- if method.dbus_input_signature %}
+        """\
+{% if method.dbus_input_signature %}
 input_signature="{{ method.dbus_input_signature }}",
-{%- endif %}
-
-{%- if method.dbus_result_signature %}
+{% endif %}
+{% if method.dbus_result_signature %}
 result_signature="{{ method.dbus_result_signature }}",
-{%- endif %}
-
-{%- if method.flags_str %}
+{% endif %}
+{% if method.is_results_args_valid_names %}
+result_args_names={{method.result_args_names_repr}},
+{% endif %}
+{% if method.flags_str %}
 flags={{ method.flags_str }},
-{%- endif %}
+{% endif %}
 """
     ),
     "generic_property_flags": (
-        r"""
-{%- if a_property.dbus_signature %}
+        """\
+{% if a_property.dbus_signature %}
 property_signature="{{ a_property.dbus_signature }}",
-{%- endif %}
-
-{%- if a_property.flags_str %}
+{% endif %}
+{% if a_property.flags_str %}
 flags={{ a_property.flags_str }},
-{%- endif %}
+{% endif %}
 """
     ),
-    "generic_header": r"""from __future__ import annotations
+    "generic_header": """\
+from __future__ import annotations
 
-from typing import Any, Dict, List, Tuple""",
-    "async_imports_header": r"""from sdbus import (
+from typing import Any, Dict, List, Tuple
+
+""",
+    "async_imports_header": """from sdbus import (
     DbusDeprecatedFlag,
     DbusInterfaceCommonAsync,
     DbusNoReplyFlag,
@@ -598,84 +632,99 @@ from typing import Any, Dict, List, Tuple""",
     dbus_method_async,
     dbus_property_async,
     dbus_signal_async,
-)""",
+)
+
+""",
     "async_main": (
-        r"""{% if include_import_header -%}
-{% include 'generic_header' %}
+        """\
+{% if include_import_header %}
+    {% include 'generic_header' %}
+
+    {% include 'async_imports_header' %}
+{% endif %}
 
-{% include 'async_imports_header' %}
-{%- endif %}
 {% for interface in interfaces %}
 
-{% include 'async_interface' %}
-{%- endfor %}
+    {% include 'async_interface' %}
+{% endfor %}
 """
     ),
     "async_interface": (
-        r"""class {{ interface.python_name }}(
+        """\
+class {{ interface.python_name }}(
     DbusInterfaceCommonAsync,
     interface_name="{{ interface.interface_name }}",
 ):
-{%- filter indent -%}
-{%- if interface.has_members -%}
-{% for method in interface.methods -%}
-{% include 'async_method' %}
-{% endfor -%}
-{% for a_property in interface.properties -%}
-{% include 'async_property' %}
-{% endfor -%}
-{% for signal in interface.signals -%}
-{% include 'async_signal' %}
-{% endfor -%}
-{%- else %}
-{% include 'generic_no_members' %}
-{% endif -%}
-{%- endfilter -%}
+{% filter indent(first=True) %}
+    {% if interface.has_members %}
+        {% for method in interface.methods %}
+            {% include 'async_method' %}
+
+        {% endfor %}
+        {% for a_property in interface.properties %}
+            {% include 'async_property' %}
+
+        {% endfor %}
+        {% for signal in interface.signals %}
+            {% include 'async_signal' %}
+
+        {% endfor %}
+    {% else %}
+        {% include 'generic_no_members' %}
+
+    {% endif %}
+{% endfilter %}
 """
     ),
     "async_method": (
-        r"""
+        """\
 @dbus_method_async(
-{%- filter indent -%}
-{%- include 'generic_method_flags' -%}
-{%- endfilter %}
+{% filter indent(first=True) %}
+    {% include 'generic_method_flags' %}
+{% endfilter %}
 )
 async def {{ method.python_name }}(
     self,
-
-{%- for arg_name, arg_type in method.args_names_and_typing %}
+{% for arg_name, arg_type in method.args_names_and_typing %}
     {{ arg_name }}: {{ arg_type }},
-{%- endfor %}
+{% endfor %}
 ) -> {{ method.result_typing }}:
     raise NotImplementedError
+
 """
     ),
     "async_property": (
-        r"""
+        """\
 @dbus_property_async(
-{%- filter indent -%}
-{%- include 'generic_property_flags' -%}
-{%- endfilter %}
+{% filter indent(first=True) %}
+    {% include 'generic_property_flags' %}
+{% endfilter %}
 )
 def {{ a_property.python_name }}(self) -> {{ a_property.typing }}:
-    raise NotImplementedError"""
+    raise NotImplementedError
+
+"""
     ),
     "async_signal": (
-        r"""
+        """\
 @dbus_signal_async(
-
-{%- if signal.dbus_signature %}
+{% if signal.dbus_signature %}
     signal_signature="{{ signal.dbus_signature }}",
-{%- endif %}
-
-{%- if signal.flags_str %}
+{% endif %}
+{% if signal.is_args_valid_names %}
+    signal_args_names={{signal.args_names_repr}},
+{% endif %}
+{% if signal.flags_str %}
     flags={{ signal.flags_str }},
-{%- endif %}
+{% endif %}
 )
 def {{ signal.python_name }}(self) -> {{ signal.typing }}:
-    raise NotImplementedError"""
+    raise NotImplementedError
+
+"""
     ),
-    "blocking_imports_header": r"""from sdbus import (
+    "blocking_imports_header": """\
+from sdbus import (
     DbusDeprecatedFlag,
     DbusInterfaceCommon,
     DbusNoReplyFlag,
@@ -686,64 +735,75 @@ def {{ signal.python_name }}(self) -> {{ signal.typing }}:
     DbusUnprivilegedFlag,
     dbus_method,
     dbus_property,
-)""",
+)
+
+""",
     "blocking_main": (
-        r"""{% if include_import_header -%}
-{% include 'generic_header' %}
+        """\
+{% if include_import_header %}
+    {% include 'generic_header' %}
+
+    {% include 'blocking_imports_header' %}
+{% endif %}
 
-{% include 'blocking_imports_header' %}
-{%- endif %}
 {% for interface in interfaces %}
 
-{% include 'blocking_interface' %}
-{%- endfor %}
+    {% include 'blocking_interface' %}
+{% endfor %}
+
 """
     ),
     "blocking_interface": (
-        r"""class {{ interface.python_name }}(
+        """\
+class {{ interface.python_name }}(
     DbusInterfaceCommon,
     interface_name="{{ interface.interface_name }}",
 ):
-{%- filter indent -%}
-{%- if interface.has_members -%}
-{% for method in interface.methods -%}
-{% include 'blocking_method' %}
-{% endfor -%}
-{% for a_property in interface.properties -%}
-{% include 'blocking_property' %}
-{% endfor -%}
-{%- else %}
-{% include 'generic_no_members' %}
-{% endif -%}
-{%- endfilter -%}
+{% filter indent(first=True) %}
+    {% if interface.has_members %}
+        {% for method in interface.methods %}
+            {% include 'blocking_method' %}
+
+        {% endfor %}
+        {% for a_property in interface.properties %}
+            {% include 'blocking_property' %}
+
+        {% endfor %}
+    {% else %}
+        {% include 'generic_no_members' %}
+
+    {% endif %}
+{% endfilter %}
 """
     ),
     "blocking_method": (
-        r"""
+        """\
 @dbus_method(
-{%- filter indent -%}
-{%- include 'generic_method_flags' -%}
-{%- endfilter %}
+{% filter indent(first=True) %}
+    {% include 'generic_method_flags' %}
+{% endfilter %}
 )
 def {{ method.python_name }}(
     self,
-
-{%- for arg_name, arg_type in method.args_names_and_typing %}
+{% for arg_name, arg_type in method.args_names_and_typing %}
     {{ arg_name }}: {{ arg_type }},
-{%- endfor %}
+{% endfor %}
 ) -> {{ method.result_typing }}:
     raise NotImplementedError
+
 """
     ),
     "blocking_property": (
-        r"""
+        """\
 @dbus_property(
-{%- filter indent -%}
-{%- include 'generic_property_flags' -%}
-{%- endfilter %}
+{% filter indent(first=True) %}
+    {% include 'generic_property_flags' %}
+{% endfilter %}
 )
 def {{ a_property.python_name }}(self) -> {{ a_property.typing }}:
-    raise NotImplementedError"""
+    raise NotImplementedError
+
+"""
     ),
 }
 
@@ -795,7 +855,12 @@ def generate_py_file(
 
     template_name = "async_main" if do_async else "blocking_main"
 
-    env = JinjaEnv(loader=DictLoader(INTERFACE_TEMPLATES))
+    env = JinjaEnv(
+        loader=DictLoader(INTERFACE_TEMPLATES),
+        trim_blocks=True,
+        lstrip_blocks=True,
+        autoescape=False,
+    )
     return env.get_template(template_name).render(
         interfaces=interfaces,
         include_import_header=include_import_header,
