@@ -19,7 +19,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 from __future__ import annotations
 
-from asyncio import Event, get_running_loop, sleep, wait_for
+from asyncio import Event, get_running_loop
+from asyncio import run as asyncio_run
+from asyncio import sleep, wait_for
 from asyncio.subprocess import create_subprocess_exec
 from typing import TYPE_CHECKING
 from unittest import SkipTest
@@ -27,6 +29,7 @@ from unittest import SkipTest
 from sdbus.exceptions import (
     DbusFailedError,
     DbusFileExistsError,
+    DbusNoReplyError,
     DbusPropertyReadOnlyError,
     DbusUnknownObjectError,
     SdBusLibraryError,
@@ -37,7 +40,7 @@ from sdbus.sd_bus_internals import (
     DbusPropertyEmitsChangeFlag,
 )
 from sdbus.unittest import IsolatedDbusTestCase
-from sdbus.utils import parse_properties_changed
+from sdbus.utils.parse import parse_properties_changed
 
 from sdbus import (
     DbusInterfaceCommonAsync,
@@ -719,6 +722,20 @@ class TestProxy(IsolatedDbusTestCase):
         with self.assertRaises(SdBusLibraryError):
             await wait_for(too_long_wait(), timeout=1)
 
+    async def test_bus_timerfd(self) -> None:
+        test_object, test_object_connection = initialize_object()
+
+        self.bus.method_call_timeout_usec = 10_000  # 0.01 seconds
+
+        loop = get_running_loop()
+
+        start = loop.time()
+
+        with self.assertRaises(DbusNoReplyError):
+            await wait_for(test_object_connection.looong_method(), timeout=1)
+
+        self.assertAlmostEqual(loop.time() - start, 0.01, delta=0.01)
+
     async def test_signal_queue_wildcard_match(self) -> None:
         test_object, test_object_connection = initialize_object()
 
@@ -975,3 +992,17 @@ class TestProxy(IsolatedDbusTestCase):
 
         with self.assertRaises(DbusUnknownObjectError):
             await test_object_connection.returns_none_method()
+
+    def test_asyncio_run_different_loops(self) -> None:
+        bus = self.bus
+
+        async def test() -> None:
+            dbus_object = DbusInterfaceCommonAsync.new_proxy(
+                "org.freedesktop.DBus",
+                "/org/freedesktop/DBus",
+                bus,
+            )
+            await wait_for(dbus_object.dbus_ping(), timeout=1)
+
+        with self.assertRaisesRegex(RuntimeError, "different loop"):
+            asyncio_run(test())
